<?php

/**
 * Define the internationalization functionality
 *
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 *
 * @link       https://www.codevision.io
 * @since      1.0.0
 *
 * @package    Codevision_Elementor_Cmb
 * @subpackage Codevision_Elementor_Cmb/includes
 */

/**
 * Define the internationalization functionality.
 *
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 *
 * @since      1.0.0
 * @package    Codevision_Elementor_Cmb
 * @subpackage Codevision_Elementor_Cmb/includes
 * @author     Codevision <info@codevision.io>
 */
class Codevision_Elementor_Cmb_i18n {


    /**
     * Load the plugin text domain for translation.
     *
     * @since    1.0.0
     */
    public function load_plugin_textdomain() {

        add_filter( 'plugin_locale', [ $this, 'handle_locales' ], 10, 2 );

        load_plugin_textdomain( CMB_SLUG,
            false,
            dirname( dirname( plugin_basename( __FILE__ ) ) ) . '/languages/' );

        $poly_lang = new \Codevision\Language\ACFPolyLang( CMB_SLUG, [
            'cmb-settings',
            'cmb-license',
        ], [
            'license_url'     => '"https://www.codevision.io/elementor-mobile-breakpoints/?utm_source=plugin-installation&utm_medium=license-notice&utm_campaign=missing-license-key"',
            'license_target'  => '"_BLANK"',
            'agency_price'    => '74,95€',
            'single_price'    => '19,95€',
            'modal_box'       => '<div class="modal" tabindex="-1" role="dialog" id="cmb-pro-modal">  <div class="modal-dialog modal-dialog-centered">    <div class="modal-content">      <div class="modal-header">        <h5 class="modal-title">Custom Mobile Breakpoints for Elementor PRO Version</h5>        <button type="button" class="close" data-dismiss="modal" aria-label="Close">          <span aria-hidden="true">&times;</span>        </button>      </div>      <div class="modal-body">        <iframe data-en-src="https://www.codevision.io/en/custom-breakpoints-checkout/"  data-de-src="https://www.codevision.io/custom-breakpoints-checkout/" class="cmb-iframe loading"></iframe>      </div>    </div>  </div></div>',
            'additional_info' => __( 'With both types your receive six month of personal support and 12 month free updates.', 'codevision-elementor-cmb' ),
        ] );

        $poly_lang->init();

    }

    /**
     *
     * Translations for the setting page of this plugin
     *
     */
    protected function settings() {

        $i18n = [
            __( 'Breakpoint Configuration', 'codevision-elementor-cmb' ),
            __( 'Enabled', 'codevision-elementor-cmb' ),
            __( 'Width', 'codevision-elementor-cmb' ),
            __( 'Height', 'codevision-elementor-cmb' ),
            __( 'Yes', 'codevision-elementor-cmb' ),
            __( 'No', 'codevision-elementor-cmb' ),
            __( 'Here you can add new breakpoint settings for your elementor editor. We already have added some of the most frequently used devices and their respective sizes for your convenience. Note that they are all disabled by default to keep the list of devices shown in your elementor editor small. If you want to add a new device just click on the button "Add entry" and enter the desired name, the width and height. We will add new devices in the future, be sure to update this plugin to get all new updates :)',
                'codevision-elementor-cmb' ),
            __( 'Please select a settings file generated by the export action of this plugin to import your settings.<br/>After adding the file, please hit "update" to start the import process.<br/><b>Note:</b> Settings with the same name already saved get overridden by the imported ones.',
                'codevision-elementor-cmb' ),
            __( 'Export your settings into a json file which can be imported again.<br/><b>Note:</b> The export only contains already saved changes in the configuration. Please make sure that in case of any changes you first hit "update" before exporting.',
                'codevision-elementor-cmb' ),
            __( 'Export Settings', 'codevision-elementor-cmb' ),
            __( 'Import strategy', 'codevision-elementor-cmb' ),
            __( 'Merge available Breakpoints', 'codevision-elementor-cmb' ),
            __( 'Override all Settings', 'codevision-elementor-cmb' ),
            __( 'If something went wrong you can always restore the devices the plugin comes with by pressing the restore button.<b>Warning:</b> This will <b>wipe</b> all custom breakpoints! Please export the settings prior wiping to have a backup in hand.',
                'codevision-elementor-cmb' ),
            __( 'Restore devices', 'codevision-elementor-cmb' ),
            __( 'Restore Devices to default', 'codevision-elementor-cmb' ),
            __( 'Upgrade to Pro now', 'codevision-elementor-cmb' ),
            __( '<h5>Custom Mobile Breakpoints Pro for Elementor</h5><p>&minus; You can add unlimited custom devices</p><p>&minus; Comes with <strong>18</strong> different devices to choose from</p><p>&minus; Export and import device lists</p><p>&minus; Device restore functionality</p><p><strong>Unlock more Options and upgrade now!</strong></p>{modal_box}',
                'codevision-elementor-cmb' ),
        ];
    }

    protected function license() {

        $i18n = [
            __( 'Notice', 'codevision-elementor-cmb' ),
            __( 'License Key', 'codevision-elementor-cmb' ),
            __( 'License Information', 'codevision-elementor-cmb' ),
            __( 'Please enter your personal license key you received by email. If you do not own a license key, or your 7 day trial has been expired you can order your personal license key <a href={license_url} target={license_target}>here</a>. The single Site License is only <strong>{single_price}</strong>. If you plan to use the plugin on more than one site, please consider buying our <strong>agency</strong> license fore unlimited site usage for only <strong>{agency_price}</strong>. {additional_info}',
                'codevision-elementor-cmb' ),

            __( 'Could not verify the License Key. Please buy a License Key <a href=%s>here</a>. As long as no valid License Key is found, the Plugin will not work correctly.',
                'codevision-elementor-cmb' ),
            __( 'You are using Custom Mobile Breakpoints for Elementor without a valid License Key. You have <strong>%%d</strong> days left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                'codevision-elementor-cmb' ),
            __( 'You are using Custom Mobile Breakpoints for Elementor without a valid License Key. You have only <strong>one</strong> day left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                'codevision-elementor-cmb' ),

            __( 'You have a valid License Key, thank you for your support', 'codevision-elementor-cmb' ),
            __( 'Your Product', 'codevision-elementor-cmb' ),
            __( 'Last Payment', 'codevision-elementor-cmb' ),
            __( 'Next Payment', 'codevision-elementor-cmb' ),
            __( 'Paid until', 'codevision-elementor-cmb' ),
            __( 'Trial Start', 'codevision-elementor-cmb' ),
            __( 'Trial End', 'codevision-elementor-cmb' ),
        ];
    }

    protected function main() {

        $i18n = [
            __( 'Custom Mobile Breakpoints for Elementor', 'codevision-elementor-cmb' ),
            __( 'https://www.codevision.io/elementor-mobile-breakpoints/', 'codevision-elementor-cmb' ),
            __( 'Finally you can add custom mobile breakpoints to your elementor editor view!', 'codevision-elementor-cmb' ),
        ];
    }

    /**
     * Set the global english speaking domain to en_EN instead of using
     * en_UK, en_US and so on
     *
     * @param $locale
     * @param $text_domain
     *
     * @return string
     */
    function handle_locales( $locale, $text_domain ) {

        if ( $text_domain !== CMB_SLUG ) {
            return $locale;
        }

        if ( strpos( $locale, 'de_' ) !== false ) {
            return 'de_DE';
        }


        if ( strpos( $locale, 'en_' ) === false ) {
            return $locale;
        }

        return 'en_EN';
    }


}
