<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.codevision.io
 * @since      1.0.0
 *
 * @package    Codevision_Elementor_Cmb
 * @subpackage Codevision_Elementor_Cmb/public
 */

use Codevision\Elementor\CustomBreakpoints;

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Codevision_Elementor_Cmb
 * @subpackage Codevision_Elementor_Cmb/public
 * @author     Codevision <info@codevision.io>
 */
class Codevision_Elementor_Cmb_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     *
     * @since    1.0.0
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version     = $version;

    }

    public function enqueue_styles() {

        $postId = get_queried_object_id();

        if ( ! $postId ) {
            return;
        }
        
        $file = sprintf( '%s/elementor-%s.css', CMB_PUBLIC_CSS, $postId );

        if ( ! file_exists( $file ) ) {
            return;
        }

        $sha = sha1( filemtime( $file ) );

        wp_enqueue_style( $this->plugin_name . '-custom-css-' . $postId, sprintf( '%scss/elementor-%s.css', plugin_dir_url( __FILE__ ), $postId ), array(), $sha, 'all' );
    }
}
