<?php


class CMB_Acf {


    public function init_bundle() {

        add_filter( 'acf/settings/path', [$this, 'acf_settings_path']  );
        add_filter( 'acf/settings/dir', [$this, 'acf_settings_dir'] );
        add_filter( 'acf/settings/load_json', [$this, 'acf_json_load_point'] );

        add_action( 'codevision/cmb/init', [$this, 'init']);
        add_action( 'codevision/cmb/add_admin_page/before', [$this, 'before_admin_page']);

        if ( get_option( 'cmb-acf-show-settings' ) === '1' ) {
            /**
             * show acf admin menu
             */
            add_filter( 'acf/settings/show_admin', '__return_true' );
        } elseif ( strpos( site_url(), 'localhost' ) === false ) {
            add_filter( 'acf/settings/show_admin', '__return_false' );
        }

        include_once( __DIR__ . '/acf/acf.php' );

        return $this;

    }

    function init() {
        if ( is_admin() && get_option('cmb-acf-disabled') === '1' ) {
            delete_option('cmb-acf-disabled');
            wp_redirect( admin_url( 'plugins.php?cmb-plugin-disabled' ) );
            exit;
        }

        if ( isset($_GET['cmb-plugin-disabled'])) {
            update_option('cmb-acf-show-settings','1');
            add_action( 'admin_notices', [ $this, 'notice_acf_disabled' ] );
        }
    }

    function before_admin_page() {
        if ( ! function_exists('acf_add_options_sub_page') ) {
            deactivate_plugins('advanced-custom-fields/acf.php');
            update_option('cmb-acf-disabled','1');
            wp_redirect( admin_url( 'plugins.php' ) );
            exit;
        }
    }

    function notice_acf_disabled() {

        $message = sprintf( esc_html__( '"%1$s" disabled "%2$s" for you. "%1$s" is bundled with an ACF version that is not compatible with your currently installed one. However, all features from your original ACF plugin will be retained and are still usable.', 'codevision-elementor-cmb' ),
            '<strong>' . CMB_NAME . '</strong>',
            '<strong>Advanced Custom Fields</strong>' );

        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

    function acf_json_load_point( $paths ) {


        // append path
        $paths[] = __DIR__ . '/acf/settings';

        // return
        return $paths;

    }

    function acf_settings_path( $path ) {

        // update path
        $path = __DIR__ . '/acf/';

        // return
        return $path;

    }

    function acf_settings_dir( $dir ) {

        $dir = plugin_dir_url( __FILE__ ) . '/acf/';

        // return
        return $dir;

    }

}


if ( ! function_exists('cv_acf_json_save_point') ) {

    add_filter( 'acf/settings/save_json', 'cv_acf_json_save_point' );

    function cv_acf_json_save_point( $path ) {

        // update path
        $path = __DIR__ . '/acf/settings';


        // return
        return $path;

    }
}

$cmb_acf = new CMB_Acf();
$cmb_acf->init_bundle();
