<?php

function cmb_get_license_manager() {

    $trial_link           = '"https://www.codevision.io/elementor-mobile-breakpoints/?utm_source=plugin-installation&utm_medium=license-notice&utm_campaign=trial-version-active"';
    $missing_license_link = '"https://www.codevision.io/elementor-mobile-breakpoints/?utm_source=plugin-installation&utm_medium=license-warning&utm_campaign=trial-version-expired"';

    $env = new \Codevision\Environment();

    $env->setPluginName( CMB_NAME )
        ->setVersion( CMB_VERSION )
        ->setBaseFile( CMB_ROOT_FILE )
        ->setBasePath( CMB_ROOT )
        ->setSlug( CMB_SLUG )
        ->setBaseUrl( plugin_dir_url( CMB_ROOT_FILE ) )
        ->setVendorUrl( plugin_dir_url( CMB_ROOT_FILE ) . 'vendor' );

    $manager = \Codevision\Licensing\Manager::getInstanceWithCompatiblityCheck( $env );

    $manager->setApiServer( CMB_LICENSE_SERVER_URL )
            ->setAuthKey( '52256523-C196-4E17-A47A-E6F93B7735CB' )
            ->setNamespace( CMB_SLUG )
            ->setLicenseInfoField( 'field_5bd1dbb456d04' )
            ->setLicenseKeyName( 'cmb_license' )
            ->setLicenseViewSlug( 'acf-options-cmb-license' )
            ->setMessages( [
                'headline'                     => CMB_NAME,
                'missing_license_admin_notice' => [
                    'Could not verify the License Key. Please buy a License Key <a href=%s>here</a>. As long as no valid License Key is found, the Plugin will not work correctly.',
                    $missing_license_link,
                ],
                'trial_period_admin_notice'    => [
                    'You are using Custom Mobile Breakpoints for Elementor without a valid License Key. You have <strong>%%d</strong> days left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
                'trial'                        => [
                    'You are using Custom Mobile Breakpoints for Elementor without a valid License Key. You have <strong>%%d</strong> days left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
                'trial_one_day_left'           => [
                    'You are using Custom Mobile Breakpoints for Elementor without a valid License Key. You have only <strong>one</strong> day left for your trial. Please consider buying <a target="_blank" href=%s>here</a>.',
                    $trial_link,
                ],
            ] )
            ->getCompatibilityCheck()
            ->setSuccessFunction( function() use ( $manager ) {

                register_deactivation_hook( CMB_ROOT_FILE, 'deactivate_codevision_elementor_cmb' );

                $init = new Codevision_Elementor_Cmb( $manager );
                $init->run();

            } )
            ->setTitle( 'Custom Mobile Breakpoints for Elementor Compatibility Check' )
            ->setEscalationScore( 20 )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'License server secure connection test [ %s ] ', CMB_LICENSE_SERVER_URL ),
                sprintf( 'We cannot make a secure connection to our license server @ %s! Please check your web-firewall, security plugin(s) and hosting settings!', CMB_LICENSE_SERVER_URL),
                function() {
                    $response = wp_remote_get( CMB_LICENSE_SERVER_URL );
                    return ! ($response instanceof \WP_Error);
                },
                20 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'PHP Version Check [ Required at least %s] ', CMB_MIN_PHP ),
                sprintf( 'Your PHP Version %s is too old, please upgrade to at least version %s to use this plugin!', PHP_VERSION, CMB_MIN_PHP ),
                function() {

                    return version_compare( PHP_VERSION, CMB_MIN_PHP, '>=' );
                },
                20 ) )
            ->add( new \Codevision\Compatibility\SimpleCheck( sprintf( 'Wordpress Version Check [ Required at least %s ]', CMB_MIN_WP ),
                sprintf( 'Your Wordpress version is too old for this plugin. At least, Wordpress version %s is required!', CMB_MIN_WP ),
                function() {

                    global $wp_version;

                    return version_compare( $wp_version, CMB_MIN_WP, '>=' );
                },
                20 ) );


    return $manager;
}

function run_codevision_elementor_cmb() {

    $manager = cmb_get_license_manager();
    $manager->init();
}

add_action( 'codevision/cmb/add_admin_page',
    function( $img_path ) {

        acf_add_options_sub_page( array(
            'page_title'  => __( 'License', 'codevision-elementor-cmb' ),
            'menu_title'  => __( 'License', 'codevision-elementor-cmb' ),
            'parent_slug' => CMB_SLUG,
            'icon_url'    => $img_path,
            'slug'        => 'acf-options-cmb-license',
        ) );
    } );

add_action( 'codevision/cmb/init_plugin',
    function() {

        run_codevision_elementor_cmb();
    } );

add_action( 'codevision/cmb/activate',
    function() {

        $manager = cmb_get_license_manager();
        $manager->init()
                ->activate();
    } );

add_action( 'codevision/cmb/deactivate',
    function() {

        $manager = cmb_get_license_manager();
        $manager->init()
                ->deactivate();
    } );

add_filter( 'acf/settings/load_json',
    function( $dir ) {

        $dir[] = CMB_REQUIRE . '/acf/settings/pro';

        return $dir;
    } );

add_action( 'wp_ajax_cmb_export',
    function() {

        check_ajax_referer( 'cmb_export', 'security' );

        if ( ! current_user_can( 'manage_options' ) ) {
            $status[ 'errorMessage' ] = __( 'Sorry, you are not allowed to export the settings' );
            wp_send_json_error( $status );
        }

        $settings = get_field( 'cmb_breakpoint_configuration', 'options' );

        if ( ! is_array( $settings ) ) {
            $settings = [];
        }

        $settings = array_map( function( $device ) {

            $device[ 'identifier' ] = $device[ 'name' ];

            return $device;
        },
            $settings );

        wp_send_json( [
            'filename' => 'cmb-breakpoint-export-' . time() . '.json',
            'success'  => true,
            'data'     => [
                'devices'  => array_values( $settings ),
                'modified' => time(),
            ],
        ] );
    } );

add_action( 'wp_ajax_cmb_restore',
    function() {

        check_ajax_referer( 'cmb_restore', 'security' );

        if ( ! current_user_can( 'manage_options' ) ) {
            $status[ 'errorMessage' ] = __( 'Sorry, you are not allowed to restore the settings' );
            wp_send_json_error( $status );
        }

        update_field( 'cmb_breakpoint_configuration', [], 'options' );

        $cmb = new \Codevision\Elementor\CustomBreakpoints();

        $cmb->setSkipImportCheck( true )
            ->import()
            ->postSaveAction();

        wp_send_json( [
            'success' => true,
        ] );
    } );

add_action( 'codevision/cmb/acf/after_save_post',
    function() {

        $import_settings = get_field( 'cmb_import', 'options' );

        if ( ! $import_settings ) {
            return;
        }

        if ( ! is_array( $import_settings ) ) {
            return;
        }

        $attachment = $import_settings[ 'file' ];
        $strategy   = $import_settings[ 'import_strategy' ];

        if ( ! $attachment ) {
            return;
        }

        $attachment_id = $attachment[ 'id' ];

        $file_data = get_attached_file( $attachment_id );

        $cmb = new \Codevision\Elementor\CustomBreakpoints();

        if ( $strategy === 'clean' ) {
            update_field( 'cmb_breakpoint_configuration', [], 'options' );
        }

        $cmb->setSettings( $file_data )
            ->setSkipImportCheck( true )
            ->import()
            ->postSaveAction();

        wp_delete_attachment( $attachment_id );
    } );

add_action( 'codevision/cmb/enqueue_script/js_data',
    function( $script_handle, $full_file, $file ) {

        if ( strpos( $file, 'cmb-acf.js' ) === false ) {
            return;
        }

        wp_localize_script( $script_handle,
            'cmb_pro_nonces',
            [
                'cmb_export'  => wp_create_nonce( 'cmb_export' ),
                'cmb_restore' => wp_create_nonce( 'cmb_restore' ),
            ] );

        wp_localize_script( $script_handle,
            'cmb_pro_message',
            [
                'cmb_restore' => __( 'Do you really want to restore to factory settings and lose all custom breakpoints?', 'codevision-elementor-cmb' ),
            ] );

    },
    10,
    3 );
